import { useShallow } from 'zustand/shallow';
import { getCurrentContent, useMenuStore } from './store/menu';
import { useEffect, useRef, useState } from 'react';
import { checkText } from './modules/get-content-type';
// import { TextEditor } from '@kevisual/markdown-editor/tiptap/editor.ts';

export const Content: React.FC = () => {
  const { currentPath } = useMenuStore(
    useShallow((state) => ({
      currentPath: state.currentPath,
    })),
  );
  const [content, setContent] = useState<string | null>(null);

  useEffect(() => {
    const fetchContent = async () => {
      if (currentPath) {
        const isText = checkText(currentPath);
        if (!isText.isText) {
          setContent('This file type is not supported for viewing.');
          return;
        }
        setContent('Loading content...');
        const content = await getCurrentContent(currentPath);
        setContent(content);
      }
    };
    fetchContent();
  }, [currentPath]);
  const ref = useRef<HTMLDivElement>(null);

  return (
    <div className='h-full w-full overflow-y-auto scrollbar px-2'>
      <pre>{content}</pre>
    </div>
  );
};
