import { Layout, Header } from '@/components/b/layouts/main/layout';
import { basename } from '@/modules/basename';
import { queryLogin } from '@/modules/query';
import { useEffect, useState } from 'react';

type Props = {
  children?: React.ReactNode;
};
export const AppLayout = (props: Props) => {
  return (
    <Layout
      header={
        <Header
          title={
            <div
              className='px-2 cursor-pointer'
              onClick={() => {
                const url = new URL(window.location.href);
                const pathname = url.pathname;
                if (pathname === basename + '/') {
                  return;
                }
                // 如果当前路径不是根路径，则跳转到根路径
                location.href = basename + '/';
              }}>
              AI Generative
            </div>
          }
          className='bg-background border-b border-b-gray-200 text-foreground'
          right={<UserInfo />}
        />
      }>
      {props.children}
    </Layout>
  );
};

type User = Awaited<ReturnType<typeof queryLogin.checkLocalUser>>;

export const UserInfo = () => {
  const [user, setUser] = useState<User | null>(null);
  useEffect(() => {
    init();
  }, []);
  const init = async () => {
    const userInfo = await queryLogin.checkLocalUser();
    const token = await queryLogin.getToken();
    if (userInfo) {
      setUser(userInfo);
    } else if (token) {
      const userinfo = await queryLogin.getLoginUserByToken(token);
      if (userinfo) {
        setUser(userinfo);
      }
    }
  };
  return (
    <div className='flex items-center gap-2'>
      {!user && (
        <div
          onClick={() => {
            const currentUrl = new URL(window.location.href);
            const loginUrl = '/user/login/';
            if (currentUrl.pathname !== loginUrl) {
              const newUrl = new URL(loginUrl, window.location.origin);
              newUrl.searchParams.set('redirect', currentUrl.pathname + currentUrl.search);
              location.href = newUrl.toString();
            }
          }}>
          login
        </div>
      )}
      {user && (
        <>
          <img src={user?.avatar || '/root/center/panda.jpg'} alt='User Avatar' className='w-8 h-8 rounded-full' />
          <span className='text-sm text-gray-700'>{user?.username}</span>
        </>
      )}
    </div>
  );
};
