import { cn } from '@/lib/utils';

type LayoutProps = {
  children?: React.ReactNode;
  header?: React.ReactNode;
  footer?: React.ReactNode;
  mainClassName?: string;
  mainStyle?: React.CSSProperties;
};
export const Layout = (props: LayoutProps) => {
  return (
    <div className='w-full h-full'>
      {props.header}
      <main
        className={cn(props.mainClassName, 'main-content')}
        style={{
          height: props.header ? 'calc(100vh - 64px)' : '100vh', // Assuming header height is 64px
          overflowY: 'auto',
          ...props.mainStyle,
        }}>
        {props.children}
      </main>
      {props.footer}
    </div>
  );
};

type HeaderProps = {
  title?: React.ReactNode;
  className?: string;
  style?: React.CSSProperties;
  right?: React.ReactNode;
  left?: React.ReactNode;
  center?: React.ReactNode;
  children?: React.ReactNode;
};
export const Header = (props: HeaderProps) => {
  return (
    <header className={cn('h-16 w-full flex items-center', props.className)} style={props.style}>
      {props.title}
      <div className='grow flex justify-between items-center px-4 '>
        {props.left && <div className='flex-1'>{props.left}</div>}
        {!props.left && <div>&nbsp;</div>}
        {props.center && <div className='flex-1 text-center'>{props.center}</div>}
        {props.right && <>{props.right}</>}
      </div>
    </header>
  );
};
